@@ -24,6 +24,7 @@
 #include <QString>
 #include <QStringList>
 #include <QRegExp>
+#include <QRegularExpression>
 #include <QFile>
 #include "k3b_i18n.h"
 
@@ -412,7 +413,7 @@ void K3b::CdrskinWriter::start()
 
     qDebug() << "***** " << d->cdrskinBinObject->name() << " parameters:\n";
     QString s = d->process.joinedArgs();
-    qDebug() << s << flush;
+    qDebug() << s << Qt::flush;
     emit debuggingOutput( d->cdrskinBinObject->name() + " command:", s);
 
     d->currentTrack = 0;
@@ -510,7 +511,8 @@ void K3b::CdrskinWriter::slotStdLine( const QString& line )
 
                 d->totalTracks = tt;
 
-                int sizeStart = line.indexOf( QRegExp("\\d"), 10 );
+                static const QRegularExpression rx("\\d");
+                int sizeStart = line.indexOf( rx, 10 );
                 int sizeEnd = line.indexOf( "MB", sizeStart );
                 track.size = line.mid( sizeStart, sizeEnd-sizeStart ).toInt(&ok);
 
@@ -552,7 +554,7 @@ void K3b::CdrskinWriter::slotStdLine( const QString& line )
                 size = d->tracks[d->currentTrack-1].size;
             }
             else {
-                qCritical() << "(K3b::CdrskinWriter) Did not parse all tracks sizes!" << endl;
+                qCritical() << "(K3b::CdrskinWriter) Did not parse all tracks sizes!" << Qt::endl;
             }
 
             if( !d->writingStarted ) {
@@ -939,4 +941,4 @@ qint64 K3b::CdrskinWriter::write( const char* data, qint64 maxSize )
     return d->process.write( data, maxSize );
 }
 
-
+#include "moc_k3bcdrskinwriter.cpp"
